// RMI client

import java.rmi.*;
import java.io.*;

public class ConferenceClient {

    // Start the Client
    public static void main(String[] args) {
        final int REGISTRYPORT = 1099;
        String registryHost = null;
        String serviceName = "ConferenceServer";
        BufferedReader stdIn = new BufferedReader(new InputStreamReader(System.in));

        // Check command line arguments
        if (args.length != 1) {
            System.out.println("Syntax: ConferenceServer HostName");
            System.exit(1);
        }
        registryHost = args[0];

        // Connessione al servizio RMI remoto
        try {
            String completeName = "//" + registryHost + ":" + REGISTRYPORT + "/" + serviceName;
            ConferenceServer serverRMI = (ConferenceServer) Naming.lookup(completeName);
            System.out.println("Client: connected to service \"" + serviceName +"\"");

            System.out.println("\nService requests until EOF");

            String service;
            System.out.print("Service (R=Registration, P=get Program): ");

            while ((service = stdIn.readLine()) != null) {

                if (service.equals("R")) {

                    boolean ok = false;

                    int g = 0;
                    System.out.print("Day (1-3)? ");
                    while (ok != true) {
                        g = Integer.parseInt(stdIn.readLine());
                        if (g < 1 || g > 3) {
                            System.out.println("Day not valid");
                            System.out.print("Day (1-3)? ");
                            continue;
                        } else {
                            ok = true;
                        }
                    }

                    ok = false;
                    String sess = null;
                    System.out.print("Session (S1 - S12)? ");

                    while (ok != true) {

                        sess = stdIn.readLine();

                        if (!sess.equals("S1") && !sess.equals("S2") && !sess.equals("S3")
                                && !sess.equals("S4") && !sess.equals("S5")
                                && !sess.equals("S6") && !sess.equals("S7")
                                && !sess.equals("S8") && !sess.equals("S9")
                                && !sess.equals("S10") && !sess.equals("S11")
                                && !sess.equals("S12")) {
                            System.out.println("Sessione not valid");
                            System.out.print("Sessione (S1 - S12)? ");
                            continue;
                        } else {
                            ok = true;
                        }
                    }

                    System.out.print("Speaker? ");
                    String speak = stdIn.readLine();
                    // no check on speaker name

                    // Send registration request
                    if (serverRMI.register(g, sess, speak)) {
                        System.out.println("Registered " + speak
                                + " for day" + g + " session " + sess);
                    } else {
                        System.out.println("Session already full: registration for day " + g + " session "
                                + sess + " failed");
                    }
                } // R
                else if (service.equals("P")) {
                    int g = 0;
                    boolean ok = false;
                    System.out.print("Day (1-3)? ");

                    while (ok != true) {
                        // intercettare la NumberFormatException
                        g = Integer.parseInt(stdIn.readLine());
                        if (g < 1 || g > 3) {
                            System.out.println("Day not valid");
                            System.out.print("Day(1-3)? ");
                            continue;
                        } else {
                            ok = true;
                        }
                    }
                    System.out.println("Program: ");
                    serverRMI.getProgram(g).print();

                } // P
                else {
                    System.out.println("Service unavailable");
                }

                System.out.print("Service (R=Registration, P=get Program): ");
            } // !EOF

        } catch (Exception e) {
            System.err.println("Client: " + e.getMessage());
            e.printStackTrace();
            System.exit(1);
        }
    }
}
